extensions [
  profiler ;; to make the model faster
  array
  table
]

breed [ managers manager ]
breed [ occupants occupant ]
breed [ zones zone ]
breed [ equipments equipment ]
;; ----------------------------------------------------------------------
;;                          populate-2Darray
;;
;; descp  : populate 2D array (arr2d) from excel file
;; param  : #filename
;; return : arr2d, arr2d-rownum, arr2d-colnum
;; excel format:
;;    <arr name>
;;    <rownum>,<colnum>
;;    <header0>      ,<header1>,   ...   ,<headern>
;;    data<row0,col0>,data<row0,col1>,...,data<row0,coln>
;;    data<row1,col0>,        ...        ,data<row1,coln>
;;    data<rown,col0>,        ...        ,data<rown,coln>
;; ----------------------------------------------------------------------
to populate-2darr-0 [#filename]
  file-open #filename
  file-close
  file-open #filename
  populate-2darr-1
end

to populate-2darr-1
  if not file-at-end? [
    let $arrname file-read-line ;; arrname
    let xstr file-read-line     ;; rownum,colnum
    tokenize xstr ","
    let arr2d_rownum read-from-string item 0 returnvalue
    let arr2d_colnum read-from-string item 1 returnvalue

    let arr2d array:from-list n-values arr2d_rownum
      [array:from-list n-values arr2d_colnum[0]]


    set xstr file-read-line ;; header
    tokenize xstr ","
    let header returnvalue

    let $rowptr 0
    while [$rowptr < arr2d_rownum]
    [
      set xstr file-read-line
      tokenize xstr ","
      let $colptr 0

      while [$colptr < arr2d_colnum]
      [
        let $val item $colptr returnvalue
        Insert2dArrItem arr2d $rowptr $colptr $val
        set $colptr ($colptr + 1)
      ]
      set $rowptr ($rowptr + 1)
    ]

    if ($arrname = "SUNRISESET") [
      set sunrisesetHdrList header
      set sunrisesetArr arr2d ]
    if ($arrname = "SKYCOVER") [
      set skycoverHdrList header
      set skycoverArr arr2d ]
    if ($arrname = "DAYLIGHTLUX") [
      set daylightHdrList header
      set daylightArr arr2d ]
    populate-2darr-1
  ]
  file-close
end
;; ----------------------------------------------------------------------
;;                         insert-to-2Darray
;; ----------------------------------------------------------------------
to Insert2dArrItem [#arr #row #col #val]
  array:set (array:item #arr #row) #col #val
  ;;print #arr ;; for testing
end

to-report Item2dArr [#arr #row #col]
  report (array:item (array:item #arr #row) #col)
end
;; ----------------------------------------------------------------------
;;                            copy-2darray
;; ----------------------------------------------------------------------
to copy-2darray [#arr_orig]
  let $rownum (array:length #arr_orig)
  let $colnum (array:length (array:item #arr_orig 0))

  set returnvalue array:from-list n-values $rownum
             [array:from-list n-values $colnum[0]]

  let $rowptr 0
  while [$rowptr < $rownum ]
  [ let $colptr 0
    while [$colptr < $colnum]
    [ let $inputdata (array:item (array:item #arr_orig $rowptr) $colptr)
      Insert2dArrItem returnvalue $rowptr $colptr $inputdata

      set $colptr ($colptr + 1)
    ]
    set $rowptr ($rowptr + 1)
  ]
end

;; ----------------------------------------------------------------------
;;                          tokenize
;; ----------------------------------------------------------------------
to tokenize [#inputstr #delim]

  set returnvalue [0]
  while [not empty? #inputstr]
  [
    let delimpos position #delim #inputstr
    let pos 0

    ifelse is-number? delimpos
    [ ;;if have not reached the last column
      let strInput substring #inputstr pos delimpos

      set returnvalue lput (TrimString strInput) returnvalue

      while [delimpos >= 0]
      [ set #inputstr remove-item 0 #inputstr
        set delimpos (delimpos - 1)
      ]
    ]
    [ ;; last column is reached
      let strInput #inputstr
      set returnvalue lput (TrimString strInput) returnvalue
      set #inputstr ""
    ]
  ]
  set returnvalue remove-item 0 returnvalue
end

;;; to trim leading and trailing spaces
to-report TrimString [ #original ]

  while [ (first #original) = " " ]
  [ set #original (remove-item 0 #original) ]

  while [ (last #original) = " " ]
  [ set #original (remove-item ((length #original) - 1) #original) ]

  report #original
end

to-report GetItemList [#str #list]
  let $pos (position #str headerListTmp)
  if is-number? $pos [ report read-from-string (item $pos #list) ]
  report 0
end

to-report GetItemListStr [#str #list]
  let $pos (position #str headerListTmp)
  if is-number? $pos [ report (item $pos #list) ]
  report " "
end

to GetDateTime
  ;; GET DATE TIME
  let $datetime (GetItemListStr "Date/Time" contentListTmp)
  tokenize $datetime "  "

  let $datestr (item 0 returnvalue)
  let $timestr (item 1 returnvalue)
  tokenize $datestr "/"
  set currentYear 2015
  set currentMonth read-from-string(item 0 returnvalue)
  set currentDay read-from-string(item 1 returnvalue)
  tokenize $timestr ":"
  set endingHour read-from-string(item 0 returnvalue)

  SetWeekDay currentDay currentMonth currentYear
;print (word weekdayStr " " currentDay "/" currentMonth "/" currentYear " " endingHour ":00:00")
end

to GetBuildingData
  set totalFloors 0
  let $zoneid 0

  let $ptr 0
  while [ $ptr < length headerListTmp ] [
    let $fieldhdr (item $ptr headerListTmp)

    if (member? ":Zone Mean Air Temperature [C](Hourly)" $fieldhdr) [
      tokenize $fieldhdr ":"
      let $floorname (item 0 returnvalue)


      create-zones 1 [
        set zoneName (word $floorname ":" (item 1 returnvalue))
        if member? "0FLOORBASEMENT" $floorname [ set zoneFloorID 0 ]
        if member? "1STFLOOR" $floorname [ set zoneFloorID 1 ]
        if member? "2NDFLOOR" $floorname [ set zoneFloorID 2 ]
        if member? "3RDFLOOR" $floorname [ set zoneFloorID 3 ]
        if member? "ATTIC" $floorname [ set zoneFloorID 4 ]
        set zoneID $zoneid
      ]
      set $zoneid ($zoneid + 1)
    ]
    set $ptr ($ptr + 1)
  ]
end


  ;;; BUILDING WIDE ;;;
to-report bldgNumOccupants
  report count occupants with [ inZone? = true ]
end

to-report electricityCost [#type]
  report ((#type / 3600000) * CentsKWH)
end

to-report bldgMeanTemperatureSP
  let $val 0
  let $nonZeroSP zones with [zoneTemperatureSetPoint > 0]
  ifelse (any? $nonZeroSP )
  [ set $val mean ([zoneTemperatureSetPoint] of $nonZeroSP)]
  [ set $val 0 ]
  report $val
end

to-report CountOccupantsWithPMV [#scale]
  let numOccupants 0
  if #scale = 0 [ set numOccupants (count occupants with [pmvValue < 1]) + (count occupants with [pmvValue > -1]) ]
  if #scale >= 1 [ set numOccupants (count occupants with [pmvValue >= #scale]) - (count occupants with [pmvValue >= (#scale + 1)]) ]
  if #scale <= -1 [ set numOccupants (count occupants with [pmvValue <= #scale]) - (count occupants with [pmvValue <= (#scale - 1)]) ]
  report numOccupants
end


to SetupLighting
  if (SimLighting) [
    LightingArrays
    SetupSkyCondition
    set luxFraction 0.18
  ]
end

to-report ConvertJToKWH [#joule]
  report precision (#joule / 3600000) 3
end

to-report ZoneTotalLux
  let $zonelux ZoneLightLux
  if (zoneLuminanceSetPoint > 0) [ set $zonelux zoneLuminanceSetPoint ]

  let $tasklightlux (zoneTaskLightNum * 228)
  report luxFraction * (zoneDaylightLux + $zonelux + $tasklightlux)
end

to UpdateElectricity
  set zoneTaskLightNum (count occupants with [taskLightON?])
  set zonePortableHeaterNum (count occupants with [portableHeaterON?])
  set zonePortableFanNum (count occupants with [portableFanON?])

  let $lightKWH (zoneLightElectricity + (zoneTaskLightNum * 100))
  let $equipmentKWH (zoneEquipmentElectricity + (zonePortableHeaterNum * 500) + (zonePortableFanNum * 500))
end

to LightingArrays
  set sunrisesetArr array:from-list n-values 12 [array:from-list n-values 63[0]]
  set skycoverArr array:from-list n-values 1 [array:from-list n-values 13[0]]
  set daylightArr array:from-list n-values 24 [array:from-list n-values 122[0]]

  populate-2darr-0 "daylight.csv"
end

to-report Sunrise
  ;; get sunrise time
  let $dayid ((currentDay * 2) - 1)
  let currentSunrise ((read-from-string (
        Item2dArr sunrisesetArr (currentMonth - 1) $dayid)) / 100)
  ifelse ((currentSunrise - floor currentSunrise) >= .3)
  [set currentSunrise (floor (currentSunrise + 1))]
  [set currentSunrise (floor currentSunrise)]

  report currentSunrise
end

to-report Sunset
  ;; get sunset time
  let $dayid (currentDay * 2)
  let currentSunset ((read-from-string (
        Item2dArr sunrisesetArr (currentMonth - 1) $dayid)) / 100)
  ifelse ((currentSunset - floor currentSunset) >= .3)
  [set currentSunset (floor (currentSunset + 1))]
  [set currentSunset (floor currentSunset)]

  report currentSunset
end

to-report percentCloudy
  report (round (read-from-string (
        Item2dArr skycoverArr 0 currentMonth)) + random 11 + random -11)
end

to SetupSkyCondition
  let tempvalue (random (93 + 112 + 160))
  if (tempvalue >= 0 AND tempvalue < 93) [set skyCondition ("Clear")]
  if (tempvalue >= 93 AND tempvalue < 205) [set skyCondition ("Partly_Cloudy")]
  if (tempvalue >= 205) [set skyCondition ("Overcast")]
end

to Daylighting
  ZoneFacadeTmpReference
  ifelse zoneFacade = "CENTER" [ set zoneDaylightLux 0 ]
  [
    let $shading "none"
    let $colstr ""
    if (skyCondition = "Clear" OR (skyCondition = "Partly_Cloudy" AND 100 >= percentCloudy))
    [ if ($shading = "none") [ (set $colstr "CLEARSKY_NOSHADING")]
      ; if ($shading = "overhang") [ (set $colstr "CLEARSKY_OVERHANG")]
      ; if ($shading = "overhang&fins") [ (set $colstr "CLEARSKY_OVERHANGFINS")]
      set $colstr (word $colstr "_" zoneFacade)
    ]
    if (skyCondition = "Overcast" OR (skyCondition = "Partly Cloudy" AND 100 < percentCloudy))
    [ if ($shading = "none") [ (set $colstr "OVERCAST_NOSHADING")]
      ; if ($shading = "overhang") [ (set $colstr "OVERCAST_OVERHANG")]
      ; if ($shading = "overhang&fins") [ (set $colstr "OVERCAST_OVERHANGFINS")]
    ]

    let $hridx ((endingHour - 1) mod 24)
    ifelse (Sunrise = 4)
    [ set $colstr (word $colstr "_" Sunrise) ]
    [ set $colstr (word $colstr "_" Sunrise "-" Sunset) ]

    let $colidx (position $colstr daylightHdrList)
;   type who type " | " type zoneName type " | " type zoneFloorID type " | " type zoneFacade type " | " type $colstr type " | " print $colidx
    set zoneDaylightLux (read-from-string(Item2dArr daylightArr $hridx $colidx))
  ]
end

to ZoneFacadeTmpReference
  if zoneName = "THE1STFLOOR:ZONE18" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:ZONE20" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:OPENWORKAREA140" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:OFFICE132ATO139" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:MLRM122FFC124T126" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:OPENOFFICEEAST141" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:OFFICE101TO103A" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:ZONE16" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:OPENOFFICEWEST" [ set zoneFacade "WEST" ]
  if zoneName = "THE1STFLOOR:LOBBY" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:OPENOFFICEEAST" [ set zoneFacade "EAST" ]
  if zoneName = "THE1STFLOOR:ELEVMACHROOM" [ set zoneFacade "CENTER" ]
  if zoneName = "THE1STFLOOR:RESTROOMS1" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:STAIRSMID" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:ELEVATORSHAFT" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:STAIRSEAST" [ set zoneFacade "EAST" ]
  if zoneName = "THE1STFLOOR:TRAININGROOM126" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:LUNCHROOM127" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:OFFICE103BTO103D" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:OFFICE113" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:LAB114TO120" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:CONFROOM109" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:DOCK121" [ set zoneFacade "NORTH" ]
  if zoneName = "THE1STFLOOR:STAIRSWEST" [ set zoneFacade "WEST" ]
  if zoneName = "THE2NDFLOOR:OFFICE237" [ set zoneFacade "NORTH" ]
  if zoneName = "THE2NDFLOOR:OFFICE226A" [ set zoneFacade "NORTH" ]
  if zoneName = "THE2NDFLOOR:OFFICE204A210A" [ set zoneFacade "NORTH" ]
  if zoneName = "THE2NDFLOOR:OFFICE220A" [ set zoneFacade "NORTH" ]
  if zoneName = "THE2NDFLOOR:OFFICE223A" [ set zoneFacade "NORTH" ]
  if zoneName = "THE2NDFLOOR:ZONE1" [ set zoneFacade "NORTH" ]
  if zoneName = "THE2NDFLOOR:OPENOFFICEWEST" [ set zoneFacade "WEST" ]
  if zoneName = "THE2NDFLOOR:OPENOFFICEEAST" [ set zoneFacade "EAST" ]
  if zoneName = "THE2NDFLOOR:ZONE6" [ set zoneFacade "NORTH" ]
  if zoneName = "THE2NDFLOOR:ELEVATORLOBBY" [ set zoneFacade "NORTH" ]
  if zoneName = "THE2NDFLOOR:RESTROOMS2" [ set zoneFacade "NORTH" ]
  if zoneName = "THE2NDFLOOR:DUCTSHAFTEAST" [ set zoneFacade "EAST" ]
  if zoneName = "THE2NDFLOOR:OFFICE211A213A" [ set zoneFacade "NORTH" ]
  if zoneName = "THE2NDFLOOR:LIBR200" [ set zoneFacade "NORTH" ]
  if zoneName = "THE2NDFLOOR:CONFROOM201A" [ set zoneFacade "NORTH" ]
  if zoneName = "THE2NDFLOOR:DATACLOSET222" [ set zoneFacade "NORTH" ]
  if zoneName = "THE3RDFLOOR:OFFICE301TO308" [ set zoneFacade "NORTH" ]
  if zoneName = "THE3RDFLOOR:OFFICE316TO318" [ set zoneFacade "NORTH" ]
  if zoneName = "THE3RDFLOOR:OFFICE320TO335" [ set zoneFacade "NORTH" ]
  if zoneName = "THE3RDFLOOR:OFFICE349TO358" [ set zoneFacade "NORTH" ]
  if zoneName = "THE3RDFLOOR:OFFICE367TO375" [ set zoneFacade "NORTH" ]
  if zoneName = "THE3RDFLOOR:OFFICEINTERIORWEST" [ set zoneFacade "WEST" ]
  if zoneName = "THE3RDFLOOR:TECHCENTER381" [ set zoneFacade "NORTH" ]
  if zoneName = "THE3RDFLOOR:OFFICEINTERIOREAST" [ set zoneFacade "EAST" ]
  if zoneName = "THE3RDFLOOR:OFFICE359TO366" [ set zoneFacade "NORTH" ]
  if zoneName = "THE3RDFLOOR:STORAGEWEST" [ set zoneFacade "WEST" ]
  if zoneName = "THE3RDFLOOR:DATACENTER" [ set zoneFacade "NORTH" ]
  if zoneName = "THE3RDFLOOR:RECEPTION342" [ set zoneFacade "NORTH" ]
  if zoneName = "THE3RDFLOOR:RESTROOMS3" [ set zoneFacade "NORTH" ]
  if zoneName = "THE3RDFLOOR:MAINCONFROOM343" [ set zoneFacade "NORTH" ]
end

to-report ZoneLightLux
if zoneName = "THE1STFLOOR:ZONE18" [ report (zoneLightElectricity / 336.1007) ]
if zoneName = "THE1STFLOOR:ZONE20" [ report (zoneLightElectricity / 819.5296) ]
if zoneName = "THE1STFLOOR:OPENWORKAREA140" [ report (zoneLightElectricity / 386.5804) ]
if zoneName = "THE1STFLOOR:OFFICE132ATO139" [ report (zoneLightElectricity / 1674.367) ]
if zoneName = "THE1STFLOOR:MLRM122FFC124T126" [ report (zoneLightElectricity / 2022.353) ]
if zoneName = "THE1STFLOOR:OPENOFFICEEAST141" [ report (zoneLightElectricity / 3055.7999) ]
if zoneName = "THE1STFLOOR:OFFICE101TO103A" [ report (zoneLightElectricity / 868.0669) ]
if zoneName = "THE1STFLOOR:ZONE16" [ report (zoneLightElectricity / 1568.1061) ]
if zoneName = "THE1STFLOOR:OPENOFFICEWEST" [ report (zoneLightElectricity / 8081.5743) ]
if zoneName = "THE1STFLOOR:LOBBY" [ report (zoneLightElectricity / 2928.615) ]
if zoneName = "THE1STFLOOR:OPENOFFICEEAST" [ report (zoneLightElectricity / 4186.5188) ]
if zoneName = "THE1STFLOOR:ELEVMACHROOM" [ report 0 ] ;report (zoneLightElectricity / ) ]
if zoneName = "THE1STFLOOR:RESTROOMS1" [ report (zoneLightElectricity / 2620.2753) ]
if zoneName = "THE1STFLOOR:STAIRSMID" [ report 0 ] ;report (zoneLightElectricity / ) ]
if zoneName = "THE1STFLOOR:ELEVATORSHAFT" [ report 0 ] ;report (zoneLightElectricity / ) ]
if zoneName = "THE1STFLOOR:STAIRSEAST" [ report 0 ] ;report (zoneLightElectricity / ) ]
if zoneName = "THE1STFLOOR:TRAININGROOM126" [ report (zoneLightElectricity / 1120.3421) ]
if zoneName = "THE1STFLOOR:LUNCHROOM127" [ report (zoneLightElectricity / 476.8933) ]
if zoneName = "THE1STFLOOR:OFFICE103BTO103D" [ report (zoneLightElectricity / 647.5853) ]
if zoneName = "THE1STFLOOR:OFFICE113" [ report (zoneLightElectricity / 296.4438) ]
if zoneName = "THE1STFLOOR:LAB114TO120" [ report (zoneLightElectricity / 1589.5168) ]
if zoneName = "THE1STFLOOR:CONFROOM109" [ report (zoneLightElectricity / 274.4725) ]
if zoneName = "THE1STFLOOR:DOCK121" [ report (zoneLightElectricity / 1446.7606) ]
if zoneName = "THE1STFLOOR:STAIRSWEST" [ report 0 ] ;report (zoneLightElectricity / ) ]
if zoneName = "THE2NDFLOOR:OFFICE237" [ report (zoneLightElectricity / 1834.4381) ]
if zoneName = "THE2NDFLOOR:OFFICE226A" [ report (zoneLightElectricity / 1577.6767) ]
if zoneName = "THE2NDFLOOR:OFFICE204A210A" [ report (zoneLightElectricity / 1131.9154) ]
if zoneName = "THE2NDFLOOR:OFFICE220A" [ report (zoneLightElectricity / 811.163) ]
if zoneName = "THE2NDFLOOR:OFFICE223A" [ report (zoneLightElectricity / 1469.9691) ]
if zoneName = "THE2NDFLOOR:ZONE1" [ report (zoneLightElectricity / 1939.7029) ]
if zoneName = "THE2NDFLOOR:OPENOFFICEWEST" [ report (zoneLightElectricity / 7309.7411) ]
if zoneName = "THE2NDFLOOR:OPENOFFICEEAST" [ report (zoneLightElectricity / 7865.5925) ]
if zoneName = "THE2NDFLOOR:ZONE6" [ report (zoneLightElectricity / 2075.4202) ]
if zoneName = "THE2NDFLOOR:ELEVATORLOBBY" [ report (zoneLightElectricity / 1531.4044) ]
if zoneName = "THE2NDFLOOR:RESTROOMS2" [ report (zoneLightElectricity / 1766.5048) ]
if zoneName = "THE2NDFLOOR:DUCTSHAFTEAST" [ report 0 ] ;report (zoneLightElectricity / ) ]
if zoneName = "THE2NDFLOOR:OFFICE211A213A" [ report (zoneLightElectricity / 2592.4435) ]
if zoneName = "THE2NDFLOOR:LIBR200" [ report (zoneLightElectricity / 757.1344) ]
if zoneName = "THE2NDFLOOR:CONFROOM201A" [ report (zoneLightElectricity / 548.2413) ]
if zoneName = "THE2NDFLOOR:DATACLOSET222" [ report (zoneLightElectricity / 263.6089) ]
if zoneName = "THE3RDFLOOR:OFFICE301TO308" [ report (zoneLightElectricity / 1849.9626) ]
if zoneName = "THE3RDFLOOR:OFFICE316TO318" [ report (zoneLightElectricity / 1175.9982) ]
if zoneName = "THE3RDFLOOR:OFFICE320TO335" [ report (zoneLightElectricity / 1841.7422) ]
if zoneName = "THE3RDFLOOR:OFFICE349TO358" [ report (zoneLightElectricity / 1762.4481) ]
if zoneName = "THE3RDFLOOR:OFFICE367TO375" [ report (zoneLightElectricity / 1874.5515) ]
if zoneName = "THE3RDFLOOR:OFFICEINTERIORWEST" [ report (zoneLightElectricity / 9063.6539) ]
if zoneName = "THE3RDFLOOR:TECHCENTER381" [ report (zoneLightElectricity / 1243.5351) ]
if zoneName = "THE3RDFLOOR:OFFICEINTERIOREAST" [ report (zoneLightElectricity / 9312.8429) ]
if zoneName = "THE3RDFLOOR:OFFICE359TO366" [ report (zoneLightElectricity / 1221.7311) ]
if zoneName = "THE3RDFLOOR:STORAGEWEST" [ report (zoneLightElectricity / 1002.9885) ]
if zoneName = "THE3RDFLOOR:DATACENTER" [ report (zoneLightElectricity / 1707.6254) ]
if zoneName = "THE3RDFLOOR:RECEPTION342" [ report 0 ] ;report (zoneLightElectricity / ) ]
if zoneName = "THE3RDFLOOR:RESTROOMS3" [ report (zoneLightElectricity / 1154.1294) ]
if zoneName = "THE3RDFLOOR:MAINCONFROOM343" [ report (zoneLightElectricity / 868.406) ]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to write-outputfile
  file-open output_fname
  while [not empty? outContent]
  [ file-print (item 0 outContent)
    set outContent remove-item 0 outContent
  ]
  file-close
end

to write-output [#inputstr]
  set outContent lput #inputstr outContent
end


to setLookUpTables
  ;; response --- environment, effort, discomfort, cost
  set bdiActionValsTbl Table:make
  table:put bdiActionValsTbl "do nothing" [ 1 1 3 1 ]
  table:put bdiActionValsTbl "window blinds" [ 1 3 2 1 ]
  table:put bdiActionValsTbl "change clothes" [ 1 3 2 1 ]
  table:put bdiActionValsTbl "portable fan" [ 2 1 2 2 ]
  table:put bdiActionValsTbl "portable heater" [ 2 1 2 2 ]
  table:put bdiActionValsTbl "task light" [ 2 1 2 2 ]
  table:put bdiActionValsTbl "thermostat" [ 3 1 1 3 ]
  table:put bdiActionValsTbl "overhead light" [ 3 1 1 3 ]


  set bdiPerceptionActionTbl Table:make
  ;;;;; original ;;;;;;;
  table:put bdiPerceptionActionTbl "too hot" [ "do nothing" "thermostat" "portable fan" "portable heater" "change clothes" ]
  table:put bdiPerceptionActionTbl "too cold" [ "do nothing" "thermostat" "portable fan" "portable heater" "change clothes" ]
  table:put bdiPerceptionActionTbl "too bright" [ "do nothing" "overhead light" "task light" "window blinds" ]
  table:put bdiPerceptionActionTbl "too dark" [ "do nothing" "overhead light" "task light" "window blinds" ]

  set clothingTbl Table:make
  table:put clothingTbl "light" 0.6
  table:put clothingTbl "heavy" 2

  set comfortPMV [-1 1]
  set comfortTemperature [20 23]    ;; in C http://en.wikipedia.org/wiki/Zone_temperature
  set comfortLux [125 175]
  ;set comfort_cotwo [0 600]          ;; http://www.engineeringtoolbox.com/co2-comfort-level-d_1024.html
end

to SetWeekday [#day #month #year]
  set listweekday [0]
  let $lasttwo (#year mod 100)
  let $frac floor ($lasttwo / 4)
  set listweekday lput $lasttwo listweekday
  set listweekday lput $frac listweekday
  set listweekday lput #day listweekday
  TableCenturies #year
  TableMonths #year #month
  set listweekday remove-item 0 listweekday

  set currentWeekday (
    item 0 listweekday + item 1 listweekday + item 2 listweekday +
    item 3 listweekday + item 4 listweekday)
  set currentWeekday ( currentWeekday mod 7)
  GetWeekdaystr
end

to GetWeekdaystr
  if (currentWeekday = 0) [ set weekdaystr "Sunday" ]
  if (currentWeekday = 1) [ set weekdaystr "Monday" ]
  if (currentWeekday = 2) [ set weekdaystr "Tuesday" ]
  if (currentWeekday = 3) [ set weekdaystr "Wednesday" ]
  if (currentWeekday = 4) [ set weekdaystr "Thursday" ]
  if (currentWeekday = 5) [ set weekdaystr "Friday" ]
  if (currentWeekday = 6) [ set weekdaystr "Saturday" ]
end

to TableCenturies [#year]
  let $yearval 0
  if (#year >= 1700 AND #year <= 1799) [ set $yearval 4 ]
  if (#year >= 1800 AND #year <= 1899) [ set $yearval 2 ]
  if (#year >= 1900 AND #year <= 1999) [ set $yearval 0 ]
  if (#year >= 2000 AND #year <= 2099) [ set $yearval 6 ]
  if (#year >= 2100 AND #year <= 2199) [ set $yearval 4 ]
  if (#year >= 2200 AND #year <= 2299) [ set $yearval 2 ]
  if (#year >= 2300 AND #year <= 2399) [ set $yearval 0 ]
  if (#year >= 2400 AND #year <= 2499) [ set $yearval 6 ]
  if (#year >= 2500 AND #year <= 2599) [ set $yearval 4 ]
  if (#year >= 2600 AND #year <= 2699) [ set $yearval 2 ]

  set listWeekday lput $yearval listWeekday
end

to TableMonths [#year #month]
  let $monthval 0
  let $isleap 0
  set $isleap (#year mod 4)
  if (#month = 1)
     [ ifelse ($isleap = 0) [ set $monthval 6 ] [ set $monthval 0 ]]
  if (#month = 2)
     [ ifelse ($isleap = 0) [ set $monthval 2 ] [ set $monthval 3 ]]
  if (#month = 3) [ set $monthval 3 ]
  if (#month = 4) [ set $monthval 6 ]
  if (#month = 5) [ set $monthval 1 ]
  if (#month = 6) [ set $monthval 4 ]
  if (#month = 7) [ set $monthval 6 ]
  if (#month = 8) [ set $monthval 2 ]
  if (#month = 9) [ set $monthval 5 ]
  if (#month = 10) [ set $monthval 0 ]
  if (#month = 11) [ set $monthval 3 ]
  if (#month = 12) [ set $monthval 5 ]

  set listWeekday lput $monthval listWeekday
end

to TableNumDays [#year #month]
  let $daysnumInMonth 0
  let $isleap 0
  set $isleap (#year mod 4)
  if (#month = 1) [ set $daysNumInMonth 31 ]
  if (#month = 2)
     [ ifelse ($isleap = 0)
       [ set $daysNumInMonth 29 ]
       [ set $daysNumInMonth 28 ]
     ]
  if (#month = 3) [ set $daysNumInMonth 31 ]
  if (#month = 4) [ set $daysNumInMonth 30 ]
  if (#month = 5) [ set $daysNumInMonth 31 ]
  if (#month = 6) [ set $daysNumInMonth 30 ]
  if (#month = 7) [ set $daysNumInMonth 31 ]
  if (#month = 8) [ set $daysNumInMonth 31 ]
  if (#month = 9) [ set $daysNumInMonth 30 ]
  if (#month = 10) [ set $daysNumInMonth 31 ]
  if (#month = 11) [ set $daysNumInMonth 30 ]
  if (#month = 12) [ set $daysNumInMonth 31 ]

  set daysNumInMonth $daysNumInMonth
end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; http://www.lumasenseinc.com/EN/products/thermal-comfort/pmv-calculation/
;http://books.google.com/books?id=-5DuyPjGwIQC&pg=PA186&lpg=PA186&dq=relationship+of+dissatisfaction+with+indoor+air+quality&source=bl&ots=R2krlWumle&sig=IrH8FTp6LtBUZupNA56CvvxZXTE&hl=en&ei=9TfiTsSFMKH00gGA8amFBg&sa=X&oi=book_result&ct=result&resnum=8&sqi=2&ved=0CGcQ6AEwBw#v=onepage&q=relationship%20of%20dissatisfaction%20with%20indoor%20air%20quality&f=true

;; -------------------------------------------------------------------------------------
;;                       CalculatePMV
;; +3 hot
;; +2 warm
;; +1 slightly warm
;; 0  neutral
;; -1 slightly cool
;; -2 cool
;; -3 cold
;; -------------------------------------------------------------------------------------


to CalculatePMV


  let MET 1                                        ;; metabolism
  let TA ([meanAirT] of myself)
  let $FTA (9 / 5 * TA + 32)                       ;; farenheit
  let $TP  (5 / 9 * ($FTA + temperatureDiff - 32)) ;; perceived temperature

  set TA $TP                                       ;; set the perceived temperature as the new TA

  if ([zoneTemperatureSetPoint] of myself > 0)
  [ set $FTA ([zoneTemperatureSetPoint] of myself)
    set TA (5 / 9 * ($FTA - 32))
  ]

  let TR  ([meanRadiantT] of myself)               ;; radiant temperature
  let RH  ([AirRelativeHumidity] of myself)        ;; relative humidity
  let VEL 0.15                                     ;; air velocity
  let CLO clothing
  let _def 0.000001
  if (CLO = _def OR MET = _def OR TA = _def OR TR = _def
    OR RH = _def OR VEL = _def)
  [ report 0.0000001 ]

  let FNPS (exp (16.6536 - 4030.183 / (TA + 235)))
  let PA (RH * 10 * FNPS)
  let ICL (0.155 * CLO)
  let M (MET * 58.15)
  let FCL 0
  ifelse ICL < 0.078
     [ set FCL (1 + 1.29 * ICL) ]
     [ set FCL (1.05 + 0.645 * ICL) ]

  let HCF (12.1 * (VEL ^ 0.5))
  let TAA (TA + 273)
  let TRA (TR + 273)

  let TCLA (TAA + (35.5 - TA) / (3.5 * (6.45 * ICL + 0.1)))
  let P1 (ICL * FCL)
  let P2 (P1 * 3.96)
  let P3 (P1 * 100.0)
  let P4 (P1 * TAA)
  let P5 (308.7 - 0.028 * M + P2 * ((TRA / 100) ^ 4))
  let XN (TCLA / 100)
  let XF (TCLA / 50)
  let HCN (1.0e-6)
  let HC (1.0e-6)
  ;XF = XN

  let N 0
  let EPS 0.0015
  while [ (abs (XN - XF)) > EPS] [
    set XF ((XF + XN) / 2)
    set HCF (12.1 * (VEL ^ 0.5))
    set HCN (2.38 * ((abs (100 * XF - TAA)) ^ 0.25))

    ifelse (HCF > HCN) [ set HC HCF ] [ set HC HCN ]

    set XN ((P5 + P4 * HC - P2 * (XF ^ 4)) / (100 + P3 * HC))
    set N (N + 1)
  ]

  let TCL (100 * XN - 273)
  ;; Skinn diff loss

  let HL1 (3.05 * 0.001 * (5733 - 6.99 * M - PA))

  ;; Sweat loss
  let HL2 0.0
  ifelse (M > 58.15)
    [ set HL2 (0.42 * (M - 58.15)) ]
    [ set HL2 0.0 ]

  ;;Latent respiration loss
  let HL3 (1.7 * 0.00001 * M * (5867 - PA))

  ;;Dry respiration loss
  let HL4 (0.0014 * M * (34 - TA))

  ;;Radiation loss
  let HL5 (3.96 * FCL * ((XN ^ 4) - ((TRA / 100) ^ 4)))

  ;;Convection loss
  let HL6 (FCL * HC * (TCL - TA))

  ;;Thermal sensation to skin tran coef
  let TS (0.303 * (exp (-0.036 * M)) + 0.028)

  let TPO 0
  ifelse (VEL < 0.2)
    [ set TPO (0.5 * TA + 0.5 * TR) ]
    [ ifelse (VEL < 0.6)
        [ set TPO (0.6 * TA + 0.4 * TR) ]
        [ set TPO (0.7 * TA + 0.3 * TR) ]
    ]

  set pmvValue (TS * (M - HL1 - HL2 - HL3 - HL4 - HL5 - HL6))
  set ppdValue (100 - 95 * ( exp (-0.03353 * (pmvValue ^ 4) - 0.2179 * (pmvValue ^ 2))));
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

globals [
  outContent
  sunrisesetArr skycoverArr daylightArr
  sunrisesetHdrList skycoverHdrList daylightHdrList

  skyCondition

  returnvalue headerListTmp contentListTmp

  bldgElectricity
  bldgEquipmentElectricity
  bldgInteriorLightsElectricity
  bldgHVACElectricity
  bldgGas

  totalFloors

  ;;; TIME ;;;
  totalHours
  daycount startDay startMonth startYear
  currentDay currentMonth currentYear
  currentWeekday weekdaystr endingHour
  listWeekday daysNumInMonth datetime


  ;;; BDI LOOKUP TABLE ;;;
  ;bdiPerception
  bdiActionValsTbl
  bdiPerceptionActionTbl
  clothingTbl

  comfortPMV
  comfortTemperature
  comfortLux

  luxFraction
]

zones-own [
  zoneID
  zoneFloorID
  zoneName
  zoneFacade

  zoneOccupantList
  zoneTenantRep

  zoneLightElectricity
  zoneEquipmentElectricity

  meanAirT
  meanRadiantT
  airRelativeHumidity
  zoneDaylightLux

  zoneTaskLightNum
  zonePortableHeaterNum
  zonePortableFanNum
  zoneConsensusValuesTbl

  zoneTemperatureSetPoint
  zoneLuminanceSetPoint
]

equipments-own [
  equipmentID
  equipmentZoneIDList
  equipmentOccupantIDList
  equipmentKWH
]

managers-own [
  managerStatusTbl
]


occupants-own [
  inZone?
  occZoneID
  occZone

  isTenantRep?

  hasEnergyMon?
  portableHeaterON?
  portableFanON?
  taskLightON?
  WindowBlindsOpen?

  workStartHour
  workEndHour
  workDays

  valOfEI
  valOfEffort
  valOfComfort
  valOfCost

  clothing
  pmvValue
  ppdValue
  temperatureDiff
  luxDiff

  lightActionPlan
  thermalActionPlan
  occupantStatusTbl
]




to SetupOccupants
  create-managers 1 [ ManagerTblResetHourly ]
  file-open occupant_fname

  let $rowfield ""
  set headerListTmp ""

  ;; read header
  if not file-at-end? [
    set $rowfield file-read-line
    tokenize $rowfield ","
    set headerListTmp returnvalue
  ]

  ;; the rest is the body
  while [ not file-at-end? ] [
    set $rowfield file-read-line
    create-occupants 1 [
      tokenize $rowfield ","
      set occZoneID (GetItemList "ZONE_ID" returnvalue)
      set workStartHour (GetItemList "WORKSTARTHR" returnvalue)
      set workEndHour (GetItemList "WORKENDHR" returnvalue)
      set workDays (GetItemListStr "WORKDAYS" returnvalue)
      set valOfEI (GetItemList "VALOFEI" returnvalue)
      set valOfEffort (GetItemList "VALOFEFFORT" returnvalue)
      set valOfComfort (GetItemList "VALOFCOMFORT" returnvalue)
      set valOfCost (GetItemList "VALOFCOST" returnvalue)
      set temperatureDiff (GetItemList "TEMPDIFF" returnvalue)
      set luxDiff (GetItemList "LIGHTDIFF" returnvalue)

      OccupantsParamsResetDaily

type occZoneID type " " type workStartHour type " " type workEndHour type " " print workDays
    ]
  ]
  print (word (count occupants) " occupants data is populated" )
  file-close
end


to-report ManagerTblGet [#key]
  let $ret false
  if table:has-key? managerStatusTbl #key
  [ report table:get managerStatusTbl #key ]
  report false
end

to ManagerTblSet [#key #val]
  table:put managerStatusTbl #key #val
end

to ManagerTblIncr [#key]
  let $val (table:get managerStatusTbl #key)
  table:put managerStatusTbl #key ($val + 1)
end

to ManagerTblDecr [#key]
  let $val (table:get managerStatusTbl #key)
  if ($val > 0) [table:put managerStatusTbl #key ($val - 1)]
end

to-report OccupantTblGet [#key]
  if table:has-key? occupantStatusTbl #key
  [ report table:get occupantStatusTbl #key]
  report false
end

to OccupantTblSet [#key #val]
  table:put occupantStatusTbl #key #val
end

to OccupantTblIncr [#key]
  let $val (table:get occupantStatusTbl #key)
  table:put occupantStatusTbl #key ($val + 1)
end

to OccupantTblDecr [#key]
  let $val (table:get occupantStatusTbl #key)
  if ($val > 0) [table:put occupantStatusTbl #key ($val - 1)]
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to runScenario
  set output_fname "AllExperiment.csv"

  let experimentID 1
  let $eplusFileid 0
  while [$eplusFileid < 2]
  [ if $eplusFileid = 0 [set eplus_fname "335Com_NLS.csv"]
    if $eplusFileid = 1 [set eplus_fname "335Com_LS.csv"]

    let $occupantFileid 0
    while [ $occupantFileid < 1 ]
    [ set occupant_fname "in_occupantdata_mix.csv"

      let $commid 0
      while [ $commid <= 1 ]
      [ if $commid = 0 [ set Communication FALSE ]
        if $commid = 1 [ set Communication TRUE ]

        let $controlid 0
        while [ $controlid <= 1 ]
        [ if $controlid = 0 [ set ZoneControl FALSE ]
          if $controlid = 1 [ set ZoneControl TRUE ]

          let $cloid 0
          while [ $cloid <= 2 ]
          [ if $cloid = 0 [ set ScenarioClo "Heavy Clothing" ]
            if $cloid = 1 [ set ScenarioClo "Light Clothing" ]
            if $cloid = 2 [ set ScenarioClo "Allow Change" ]


            setup experimentID
            go experimentID

            set experimentID (experimentID + 1)
            set $cloid ($cloid + 1)
          ]
          set $controlid ($controlid + 1)
        ]
        set $commid ($commid + 1)
      ]
      set $occupantFileid ($occupantFileid + 1)
    ]
    set $eplusFileid ($eplusFileid + 1)
  ]
end

to setup [experimentID]
  ct
  clear-all-plots

set sunrisesetArr 0
set skycoverArr 0
set daylightArr 0
set sunrisesetHdrList  0
set skycoverHdrList  0
set daylightHdrList 0
set skyCondition 0
set returnvalue  0
set headerListTmp  0
set contentListTmp 0
set bldgElectricity  0
set bldgEquipmentElectricity 0
set bldgInteriorLightsElectricity 0
set bldgHVACElectricity 0
set bldgGas 0
set totalFloors 0
set totalHours 0
set daycount  0
set startDay  0
set startMonth  0
set startYear 0
set currentDay  0
set currentMonth  0
set currentYear 0
set currentWeekday  0
set weekdaystr  0
set endingHour 0
set listWeekday  0
set daysNumInMonth  0
set datetime 0
set bdiActionValsTbl 0
set bdiPerceptionActionTbl 0
set clothingTbl 0
set comfortPMV 0
set comfortTemperature 0
set comfortLux 0
set luxFraction 0
set outContent []

  setLookUpTables
  SetupOccupants
  SetupLighting

  if experimentID = 1
  [
    write-output (word "current month,EndingHour,ExperimentID,LoadShedding,OccupantType,Communication,ZoneControl,Clothing,Electric_Total,Electric_Equipment,Electric_Lights,Electric_HVAC,"
      "MATemperature,TempSP,ThermalDiscomfort0,ThermalDiscomfort1,ThermalDiscomfort2,ThermalDiscomfort3,ThermalDiscomfort4,ThermalDiscomfort5,"
      "LightDiscomfort0,LightDiscomfort1,LightDiscomfort2,LightDiscomfort3,LightDiscomfort4,LightDiscomfort5,"
      "ThermalCold0,ThermalHot0,ThermalNormal0,ThermalCold1,ThermalHot1,ThermalNormal1,ThermalCold2,ThermalHot2,ThermalNormal2,"
      "ThermalCold3,ThermalHot3,ThermalNormal3,ThermalCold4,ThermalHot4,ThermalNormal4,ThermalCold5,ThermalHot5,ThermalNormal5,"
      "LightDark0,LightBright0,LightNormal0,LightDark1,LightBright1,LightNormal1,LightDark2,LightBright2,LightNormal2,"
      "LightDark3,LightBright3,LightNormal3,LightDark4,LightBright4,LightNormal4,LightDark5,LightBright5,LightNormal5,"
      "occTaskLight,occWindowBlinds,occClothes,occPortHeater,occPortFan,trThermostat,trOverheadLight,"
      "manThermostat,manOverheadLight,manDoNothing")
    if file-exists? output_fname [ file-close file-delete output_fname ]
  ]



end

to go [experimentID]
  file-open eplus_fname
file-close
  file-open eplus_fname

  if not file-at-end? [
    tokenize file-read-line ","
    set headerListTmp returnvalue
    GetBuildingData
    print (word count zones " zones data is populated")
  ]
                                                                                               ;ask zones [ type zoneID type " " show zoneName ]
  ;; read data
  while [ not file-at-end? ] [
    tokenize file-read-line ","
    set contentListTmp returnvalue
    GetDateTime

    set bldgElectricity (GetItemList "Electricity:Facility [J](Hourly)" contentListTmp)
    set bldgEquipmentElectricity (GetItemList "InteriorEquipment:Electricity [J](Hourly)" contentListTmp)
    set bldgInteriorLightsElectricity (GetItemList "InteriorLights:Electricity [J](Hourly)" contentListTmp)
    set bldgHVACElectricity (GetItemList "Electricity:HVAC [J](Hourly)" contentListTmp)
    set bldgGas (GetItemList "Gas:Plant [J](Hourly)" contentListTmp)                              ;    type bldgElectricity type " " type bldgEquipmentElectricity type " " type bldgHVACElectricity print bldgInteriorLightsElectricity


    ask managers [ ManagerTblResetHourly ]

    ask zones [
      if (SimLighting) [ Daylighting ]
      if (endingHour = 1) [
        set zoneOccupantList []
        set zoneTenantRep nobody
        set zoneConsensusValuesTbl table:make
        set zoneTemperatureSetPoint 0
        set zoneLuminanceSetPoint 0

      ]
        set meanAirT (GetItemList (
          word zoneName ":Zone Mean Air Temperature [C](Hourly)") contentListTmp)
        set meanRadiantT (GetItemList (
          word zoneName ":Zone Mean Radiant Temperature [C](Hourly)") contentListTmp)
        set airRelativeHumidity (GetItemList (
          word zoneName ":Zone Air Relative Humidity [%](Hourly)") contentListTmp)
        set zoneLightElectricity (GetItemList (
          word zoneName ":Zone Lights Electric Energy [J](Hourly)") contentListTmp)
        set zoneEquipmentElectricity (GetItemList (
          word zoneName ":Zone Electric Equipment Electric Energy [J](Hourly)") contentListTmp)

      goMASBehavior
    ]
    update-plots
    write-output (word currentMonth "," endingHour ","
      experimentID "," (ifelse-value (member? "_LS" eplus_fname) [1][0]) "," (remove ".csv" (remove "in_occupantdata_" occupant_fname)) ","
      (ifelse-value (Communication) [1] [0]) ","
      (ifelse-value (ZoneControl) [1] [0]) ","
      ScenarioClo "," round (electricityCost bldgElectricity) "," round (electricityCost bldgEquipmentElectricity) "," round (electricityCost bldgInteriorLightsElectricity) "," round (electricityCost bldgHVACElectricity) ","
      round (9 / 5 * (mean [meanAirT] of zones) + 32) "," bldgMeanTemperatureSP ","
      (BldgThermalDiscomfort 0) "," (BldgThermalDiscomfort 1) "," (BldgThermalDiscomfort 2) "," (BldgThermalDiscomfort 3) "," (BldgThermalDiscomfort 4) "," (BldgThermalDiscomfort 5) ","
      (BldgLightDiscomfort 0) "," (BldgLightDiscomfort 1) "," (BldgLightDiscomfort 2) "," (BldgLightDiscomfort 3) "," (BldgLightDiscomfort 4) "," (BldgLightDiscomfort 5) ","
      (count occupants with [OccupantTblGet "thermalPerception0" = "too cold"]) ","
      (count occupants with [OccupantTblGet "thermalPerception0" = "too hot"]) ","
      (count occupants with [OccupantTblGet "thermalPerception0" = "normal"]) ","
      (count occupants with [OccupantTblGet "thermalPerception1" = "too cold"]) ","
      (count occupants with [OccupantTblGet "thermalPerception1" = "too hot"]) ","
      (count occupants with [OccupantTblGet "thermalPerception1" = "normal"]) ","
      (count occupants with [OccupantTblGet "thermalPerception2" = "too cold"]) ","
      (count occupants with [OccupantTblGet "thermalPerception2" = "too hot"]) ","
      (count occupants with [OccupantTblGet "thermalPerception2" = "normal"]) ","
      (count occupants with [OccupantTblGet "thermalPerception3" = "too cold"]) ","
      (count occupants with [OccupantTblGet "thermalPerception3" = "too hot"]) ","
      (count occupants with [OccupantTblGet "thermalPerception3" = "normal"]) ","
      (count occupants with [OccupantTblGet "thermalPerception4" = "too cold"]) ","
      (count occupants with [OccupantTblGet "thermalPerception4" = "too hot"]) ","
      (count occupants with [OccupantTblGet "thermalPerception4" = "normal"]) ","
      (count occupants with [OccupantTblGet "thermalPerception5" = "too cold"]) ","
      (count occupants with [OccupantTblGet "thermalPerception5" = "too hot"]) ","
      (count occupants with [OccupantTblGet "thermalPerception5" = "normal"]) ","
      (count occupants with [OccupantTblGet "lightPerception0" = "too dark"]) ","
      (count occupants with [OccupantTblGet "lightPerception0" = "too bright"]) ","
      (count occupants with [OccupantTblGet "lightPerception0" = "normal"]) ","
      (count occupants with [OccupantTblGet "lightPerception1" = "too dark"]) ","
      (count occupants with [OccupantTblGet "lightPerception1" = "too bright"]) ","
      (count occupants with [OccupantTblGet "lightPerception1" = "normal"]) ","
      (count occupants with [OccupantTblGet "lightPerception2" = "too dark"]) ","
      (count occupants with [OccupantTblGet "lightPerception2" = "too bright"]) ","
      (count occupants with [OccupantTblGet "lightPerception2" = "normal"]) ","
      (count occupants with [OccupantTblGet "lightPerception3" = "too dark"]) ","
      (count occupants with [OccupantTblGet "lightPerception3" = "too bright"]) ","
      (count occupants with [OccupantTblGet "lightPerception3" = "normal"]) ","
      (count occupants with [OccupantTblGet "lightPerception4" = "too dark"]) ","
      (count occupants with [OccupantTblGet "lightPerception4" = "too bright"]) ","
      (count occupants with [OccupantTblGet "lightPerception4" = "normal"]) ","
      (count occupants with [OccupantTblGet "lightPerception5" = "too dark"]) ","
      (count occupants with [OccupantTblGet "lightPerception5" = "too bright"]) ","
      (count occupants with [OccupantTblGet "lightPerception5" = "normal"]) ","
      (count occupants with [OccupantTblGet "lightActTaskLight"]) ","
      (count occupants with [OccupantTblGet "lightActWindowBlinds"]) ","
      (count occupants with [OccupantTblGet "thermalActClothes"]) ","
      (count occupants with [OccupantTblGet "thermalActHeater"]) ","
      (count occupants with [OccupantTblGet "thermalActFan"]) ","
      (count occupants with [OccupantTblGet "thermalActThermostat"]) ","
      (count occupants with [OccupantTblGet "lightActOverheadLight"]) ","
      (sum [ManagerTblGet "thermalActThermostatCount"] of managers) ","
      (sum [ManagerTblGet "lightActOverheadLightCount"] of managers) ","
      (sum [ManagerTblGet "ActDoNothingCount"] of managers))
  ]
  file-close
  write-outputfile
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; BUILDING OCCUPANT BEHAVIOR ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to goMASBehavior
  ;;; reset behavior parameters

  ask occupants with [ occZoneID = [zoneID] of myself ]
  [ if endingHour = 1 [ OccupantsParamsResetDaily ]
    OccupantTblResetHourly
    OccupantOccupancyStatus
  ]

  let $occupantsInZoneSet (occupants with [occZone = myself])

  if (count $occupantsInZoneSet > 0)
  [ BehaviorIndividual1 $occupantsInZoneSet
    BehaviorTenantRep
    BehaviorManager
    BehaviorIndividual2 $occupantsInZoneSet
  ]
end

to BehaviorIndividual1 [ #occupants ]
  ;;; assign tenant behavior
  if (zoneTenantRep = nobody)
  [ set zoneTenantRep (one-of #occupants)
    ask zoneTenantRep [ set isTenantRep? true ]
  ]

  (OccupantPerceptionStatus #occupants 0)

  ask #occupants
  [ if SimLighting
    [ set lightActionPlan []
      if ((OccupantTblGet "lightPerception0") != "normal")
      [ set lightActionPlan (BDIOccupantAction (OccupantTblGet "lightPerception0"))]
    ]
    if SimThermal
    [ set thermalActionPlan []
      if ((OccupantTblGet "thermalPerception0") != "normal")
      [ set thermalActionPlan (BDIOccupantAction (OccupantTblGet "thermalPerception0")) ]
    ]                                                                                             ; if not empty? thermalActionPlan [type endingHour type " OCC1: " print thermalActionPlan  ]
  ]
end

to BehaviorTenantRep
                                                                                                  ;type "BEFORE TENANTREP : " print zoneConsensusValuesTbl
  if (table:length zoneConsensusValuesTbl > 0)
  [ ask zoneTenantRep
    [ if(ZoneControl = true)
      [ foreach table:keys ([zoneConsensusValuesTbl] of myself)
        [ let $valueList (table:get [zoneConsensusValuesTbl] of myself ?)
          let $isMajority? (ifelse-value ((item 2 $valueList > (item 3 $valueList) / 2) ) [true] [false])
          ifelse ($isMajority?)
          [                                                                                       ;type "hr= " type endingHour type " zone= " type myself type " AT TENANTREP "  print ([zoneConsensusValuesTbl] of myself)
            if (? = "thermostat") [ ActThermostat]
            if (? = "overhead light") [ActOverheadLight ]
          ]
          []; (OccupantTblIncr "ActDoNothingCount") ]
          ask myself [ table:remove zoneConsensusValuesTbl ?]
        ]
      ]
    ]
  ]
                                                                                                   ;type "hr= " type endingHour type " zone= " type self type " AFTER TENANTREP : " print zoneConsensusValuesTbl
end

to BehaviorManager
  if (table:length zoneConsensusValuesTbl > 0)
  [ ask managers
    [ ifelse (Communication = false)
      [ (ManagerTblIncr "ActDoNothingCount") ]
      [ foreach table:keys ([zoneConsensusValuesTbl] of myself)
        [ ;;; majority rule
          let $valueList (table:get [zoneConsensusValuesTbl] of myself ?)
          let $isMajority? (ifelse-value ((item 2 $valueList > (item 3 $valueList) / 2) ) [true] [true])
          ifelse ($isMajority?)
          [                                                                                         ;type "hr= " type endingHour type " zone= " type myself type " AT MANAGER : " print ([zoneConsensusValuesTbl] of myself)
            if (? = "thermostat") [ ActThermostat ]
            if (? = "overhead light") [ ActOverheadLight ]
          ]
          [ (ManagerTblIncr "ActDoNothingCount") ]
          ask myself [ table:remove zoneConsensusValuesTbl ?]
        ]
      ]
                                                                                                    ;type ManagerTblGet "thermalActThermostatCount" type " "
    ]
  ]
                                                                                                   ; type (sum [ManagerTblGet "thermalActThermostatCount"] of managers) type " AFTER MANAGER : " print zoneConsensusValuesTbl
end

to BehaviorIndividual2 [#occupants]
  let $trial 1
  (occupantPerceptionStatus #occupants $trial)

  while [$trial <= 5]
  [ ask #occupants
    [                                                                                                ;if (OccupantTblGet "lightPerception0" != OccupantTblGet "lightPerception1") [type OccupantTblGet "lightPerception0" type " " print OccupantTblGet "lightPerception1"]
      if (SimThermal AND empty? thermalActionPlan = false)
      [ let $thermalPerception (OccupantTblGet (word "thermalPerception" $trial))
        ifelse ($thermalPerception != "normal")
        [ ifelse ($thermalPerception = "too hot")
          [ set thermalActionPlan remove "portable heater" thermalActionPlan ]
          [ set thermalActionPlan remove "portable fan" thermalActionPlan ]

        if (member? "thermostat" thermalActionPlan)
           [set thermalActionPlan remove "thermostat" thermalActionPlan]                                ;if not empty? thermalActionPlan [ type $thermalperception type " OCC2: " print thermalActionPlan]
        let $firstThermalAction first thermalActionPlan                                                 ;type "OCC2 thermal: " print $firstThermalAction

        if ($firstThermalAction = "do nothing") [ActDoNothing $thermalPerception]
        if ($firstThermalAction = "change clothes") [if ScenarioClo = "Allow Change" [ActChangeClothes $thermalPerception]]
        if ($firstThermalAction = "portable fan") [ActPortableFan $thermalPerception]
        if ($firstThermalAction = "portable heater") [ActPortableHeater $thermalPerception]
        ] [set thermalActionPlan []]
      ]
      if (SimLighting AND empty? lightActionPlan = false)
      [ let $lightPerception (OccupantTblGet (word "lightPerception" $trial))
        ifelse ($lightPerception != "normal")
        [
          if (member? "overhead light" lightActionPlan)
             [set lightActionPlan remove "overhead light" lightActionPlan]                                     ; type "OCC lighting:" print $firstLightAction
          let $firstLightAction first lightActionPlan

          if ($firstLightAction = "do nothing") [ActDoNothing $lightPerception]
          if ($firstLightAction = "task light") [ActTaskLight $lightPerception]
          if ($firstLightAction = "windowblinds") [ActWindowBlinds $lightPerception]
        ] [set lightActionPlan []]
      ]
    ]
    (OccupantPerceptionStatus #occupants ($trial + 1))
    set $trial ($trial + 1)
  ]
end


to OccupantsParamsResetDaily
  set occZone nobody
  set inZone? false
  set isTenantRep? false

  set pmvValue 0
  set portableHeaterON? false
  set portableFanON? false
  set taskLightON? false
  set WindowBlindsOpen? false

  if ScenarioClo = "Heavy Clothing" [ set clothing (table:get clothingTbl "heavy") ]
  if ScenarioClo = "Light Clothing" [ set clothing (table:get clothingTbl "light") ]
  if ScenarioClo = "Allow Change" [ set clothing (table:get clothingTbl "light") ]

end

to ManagerTblResetHourly
  let $statusList
  [ ["ActDoNothingCount" 0]
    ["lightActOverheadLightCount" 0]
    ["thermalActThermostatCount" 0]]
  set managerStatusTbl (table:from-list $statusList)
end

to OccupantTblResetHourly
  let $statusList
  [ ["lightAction" "do nothing"]
    ["lightPerception" "normal"]
    ["lightActDoNothing" false]
    ["lightActTaskLight" false]
    ["lightActWindowBlinds" false]
    ["thermalAction" "do nothing"]
    ["thermalActDoNothing" false]
    ["thermalActClothes" false]
    ["thermalActHeater" false]
    ["thermalActFan" false]
    ["thermalActThermostat" false]
    ["lightActOverheadLight" false]
    ["lightPerception0" "normal"]
    ["thermalPerception0" "normal"]
    ["lightPerception1" "normal"]
    ["thermalPerception1" "normal"]
    ["lightPerception2" "normal"]
    ["thermalPerception2" "normal"]
    ["lightPerception3" "normal"]
    ["thermalPerception3" "normal"]
    ["lightPerception4" "normal"]
    ["thermalPerception4" "normal"]
    ["lightPerception5" "normal"]
    ["thermalPerception5" "normal"]
    ["lightDiscomfort0" false]
    ["thermalDiscomfort0" false]
    ["lightDiscomfort1" false]
    ["thermalDiscomfort1" false]
    ["lightDiscomfort2" false]
    ["thermalDiscomfort2" false]
    ["lightDiscomfort3" false]
    ["thermalDiscomfort3" false]
    ["lightDiscomfort4" false]
    ["thermalDiscomfort4" false]
    ["lightDiscomfort5" false]
    ["thermalDiscomfort5" false]
  ]
  set occupantStatusTbl (table:from-list $statusList)
end

to OccupantOccupancyStatus
    let $currentHour (endingHour - 1)
    ifelse ((workdays = "M-Sun"
      AND ($currentHour * 100) >= workStartHour
        AND ($currentHour * 100) <= workEndHour)
       OR
       (workDays = "M-F"
         AND currentWeekDay >= 1
         AND currentWeekDay <= 5
         AND ($currentHour * 100) >= workStartHour
        AND ($currentHour * 100) <= workEndHour))
    [ if (not inZone?)
      [OccupantEnterZone]
    ]
    [ if (inZone?) [ OccupantLeaveZone] ]
end

to OccupantEnterZone
  ;; the first occupant enter zone becomes tenant representative

  ask myself [ set zoneOccupantList lput myself zoneOccupantList ]
  set occZone myself
  set inZone? true
  set color blue
  show-turtle
end

to OccupantLeaveZone
  ;;; if the person is tenant representative, replace with the next in the list
  ask myself
  [ set zoneOccupantList remove myself zoneOccupantList
    ifelse (empty? zoneOccupantList)
    [ set zoneTenantRep nobody ]
    [ if ([isTenantRep?] of myself)
      [ set zoneTenantRep (first zoneOccupantList)
        ask zoneTenantRep [ set isTenantRep? true ]
      ]
    ]
  ]
  OccupantsParamsResetDaily
  hide-turtle
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to OccupantPerceptionStatus [#occupants #assertID]
  ask #occupants
  [ if SimLighting [ BDILightingPerception #assertID ]
    if SimThermal [ BDIThermalPerception #assertID ]
  ]
end

to BDIThermalPerception [#id]
  let #perception (word "thermalPerception" #id)
  let #discomfort (word "thermalDiscomfort" #id)
  CalculatePMV
                                                                                                    ;if (pmvValue != 0) [show pmvValue]
  ifelse (pmvValue >= first comfortPMV AND pmvValue <= last comfortPMV)
  [ (OccupantTblSet #perception "normal")
    (OccupantTblSet #discomfort false)
  ]
  [ if (pmvValue > last comfortPMV)
    [ (OccupantTblSet #perception "too hot")
      (OccupantTblSet #discomfort true)
    ]
    if (pmvValue < first comfortPMV)
    [ (OccupantTblSet #perception "too cold")
      (OccupantTblSet #discomfort true)
    ]
  ]
end


to BDILightingPerception [#id]
  let #perception (word "lightPerception" #id)
  let #discomfort (word "lightDiscomfort" #id)

  let $perceivedLux ([ZoneTotalLux] of myself + luxDiff)
  if not WindowBlindsOpen? [ set $perceivedLux ($perceivedLux - ([zoneDaylightLux] of myself) / 5) ]
                                                                                                           ;type [ZoneTotalLux] of myself type " " type luxDiff type " " type $perceivedLux type " " print comfortLux
  ifelse ($perceivedLux >= first comfortLux AND $perceivedLux <= last comfortLux)
  [ (OccupantTblSet #perception "normal")
    (OccupantTblSet #discomfort false)
  ]
  [ if ($perceivedLux > last comfortLux)
    [ (OccupantTblSet #perception "too bright")
      (OccupantTblSet #discomfort true)
    ]
    if ($perceivedLux < first comfortLux)
    [ (OccupantTblSet #perception "too dark")
      (OccupantTblSet #discomfort true)
    ]
  ]
end


to-report BDIOccupantAction [#perception]
  let $returnActionList []
  let $sortedAllActionValueList (BDIActionValuesSetSort #perception)

  if (length $sortedAllActionValueList > 0)
  [ foreach $sortedAllActionValueList
    [ set $returnActionList lput (first ?) $returnActionList ]
  ]

  ;;;;;;;;;;;;;;;; STRATEGIZE MULTI DECISION FOR CENTRALIZED ACTION ;;;;;;;;;;;;;;;;
  let $firstAction (first $returnActionList)
  let isConsensus false
  if ($firstAction = "thermostat" OR $firstAction = "overhead light")
  [ ask myself
    [ ifelse (table:has-key? zoneConsensusValuesTbl $firstAction)
      [ let $valueList (table:get zoneConsensusValuesTbl $firstAction)
        set $valueList replace-item 1 $valueList myself                  ;;; update last occupant for LIFO
        set $valueList replace-item 2 $valueList ((item 2 $valueList) + 1) ;;; update occupant counter for majority
        table:put zoneConsensusValuesTbl $firstAction $valueList
      ]
      [ ;type self type " " type myself type " " print $firstAction
        let $valueList []
        set $valueList lput myself $valueList   ;;; first for FIFO decision
        set $valueList lput myself $valueList   ;;; last  for LIFO decision
        set $valueList lput 1 $valueList        ;;; count performer for majority decision
        set $valueList lput (length zoneOccupantList) $valueList ;;; total occupant in zone
        table:put zoneConsensusValuesTbl $firstAction $valueList
      ]
    ]
  ]
  report $returnActionList
end

to-report BDIActionValuesSetSort [#perception]
  let $allValueList []
  let $allActionValueTbl table:make
  let $actionList (table:get bdiPerceptionActionTbl #perception)
  let $sortedAllActionValueList []
                                                                                                    ;type "ACTIONS= " print $actionList
  foreach $actionList
  [ let $action ?
    let $valList (CalculateUtility $action)
    ;;;;;;;;;; CONSIDER ALL ACTIONS
    let $totalValues (sum $valList)
    set $allValueList lput $totalValues $allValueList
    table:put $allActionValueTbl $action $totalValues
  ]

  if (table:length $allActionValueTbl > 0)
  [                                                                                                 ;type "TABLE= " print $allActionValueTbl
    let $allActionValueList (table:to-list $allActionValueTbl)
                                                                                                    ;type " UNSORTED= " print $allActionValueList
    set $sortedAllActionValueList (sort-by [last ?1 > last ?2] $allActionValueList)
                                                                                                    ;type " SORTED= " type self type " "  print $sortedAllActionValueList print ""
  ]

  report $sortedAllActionValueList
end


to-report CalculateUtility [ #action ]
  let $util []
  let $valList (table:get bdiActionValsTbl #action)
  set $util lput (valOfEI * (item 0 $valList)) $util
  set $util lput (valOfEffort * (item 1 $valList)) $util
  set $util lput (valOfComfort * (item 2 $valList)) $util
  set $util lput (valOfCost * (item 3 $valList)) $util

  report $util
end

to-report BldgThermalDiscomfort [#id]
  let $add 0
  if (SimThermal) ; AND DiscomfortAdder)
  [ if Communication = false [ set $add ($add + 1) ]
    if ZoneControl = false [ set $add ($add + 1) ] ]

  report (count occupants with [OccupantTblGet (word "thermalDiscomfort" #id)]) + $add
end

to-report BldgLightDiscomfort [#id]
  let $add 0
  if (SimLighting) ; AND DiscomfortAdder)
  [ if Communication = false [ set $add ($add + 1) ]
    if ZoneControl = false [ set $add ($add + 1) ]]
  report (count occupants with [OccupantTblGet (word "lightDiscomfort" #id)]) + $add
end

to-report BldgOccupantEffort
  report ((count occupants with [OccupantTblGet "lightActTaskLight"]) +
  (count occupants with [OccupantTblGet "lightActWindowBlinds"]) +
  (count occupants with [OccupantTblGet "thermalActClothes"]) +
  (count occupants with [OccupantTblGet "thermalActHeater"]) +
  (count occupants with [OccupantTblGet "thermalActFan"]) +
  (count occupants with [OccupantTblGet "thermalActThermostat"]) +
  (count occupants with [OccupantTblGet "lightActOverheadLight"]))
end

to ActDoNothing [#perception]
  if (#perception = "too hot" OR #perception = "too cold")
  [ (OccupantTblSet "thermalActDoNothing" true)
    set thermalActionPlan remove "do nothing" thermalActionPlan
  ]
  if (#perception = "too dark" OR #perception = "too bright")
  [ (OccupantTblSet "lightActDoNothing" true)
    set lightActionPlan remove "do nothing" lightActionPlan
  ]
end

to ActChangeClothes [ #perception ]
  let $CLOTemp 0
  if #perception = "too hot" [ set clothing (table:get clothingTbl "light") ]
  if #perception = "too cold" [ set clothing (table:get clothingTbl "heavy") ]

  OccupantTblSet "thermalActClothes" true
  set thermalActionPlan remove "change clothes" thermalActionPlan
end

to ActPortableHeater [ #perception ]
  ifelse portableHeaterON? = true
  [ if #perception = "too hot"
    [ set portableHeaterON? false
      OccupantTblSet "thermalActHeater" true
    ]]
  [ if #perception = "too cold"
    [ set portableHeaterON? true
      OccupantTblSet "thermalActHeater" true
    ]]
  set thermalActionPlan remove "portable heater" thermalActionPlan
end

to ActPortableFan [ #perception]
  ifelse portableFanON? = true
  [ if #perception = "too cold"
    [ set portableFanON? false
      OccupantTblSet "thermalActFan" true
    ]]
  [ if #perception = "too hot"
    [ set portableFanON? true
      OccupantTblSet "thermalActFan" true
    ]]
  set thermalActionPlan remove "portable fan" thermalActionPlan
end

to ActTaskLight [ #perception ]
  ifelse taskLightON? = true
  [ if #perception = "too bright"
    [ set taskLightON? false
      OccupantTblSet "lightActTaskLight" true
    ]]
  [ if #perception = "too dark"
    [ set taskLightON? true
      OccupantTblSet "lightActTaskLight" true
    ]]
  set lightActionPlan remove "task light" lightActionPlan
end

to ActWindowBlinds [ #perception ]
  ifelse WindowBlindsOpen? = true
  [ if #perception = "too bright"
    [ set WindowBlindsOpen? false
      OccupantTblSet "lightActWindowBlinds" true
    ]]
  [ if #perception = "too dark"
    [ set WindowBlindsOpen? true
      OccupantTblSet "lightActWindowBlinds" true
    ]]
  set lightActionPlan remove "window blinds" lightActionPlan
end

to ActThermostat
  let $temperaturesp 0
  ask myself [
    ;; convert list of agents to agentset
    let $occupantset occupants with [member? self ([zoneOccupantList] of myself) ]

    let $meanTempDiff (mean [temperatureDiff] of $occupantset)
    ifelse (currentMonth > 4 AND currentMonth < 9)
    [ set $temperaturesp ((9 / 5 * (last comfortTemperature) + 32) + $meanTempDiff) ]
    [ set $temperaturesp ((9 / 5 * (first comfortTemperature) + 32) + $meanTempDiff) ]

    set zoneTemperatureSetPoint $temperaturesp
                                                                                              ;if (zoneTemperatureSetPoint > 0) [ show zoneTemperatureSetPoint]
  ]

  if (self = one-of managers) [(ManagerTblIncr "thermalActThermostatCount")]
  if (self = one-of occupants) [ OccupantTblSet "thermalActThermostat" true ]
end

to ActOverheadLight
  ask myself [
    let $occupantset occupants with [member? self ([zoneOccupantList] of myself) ]
    let $meanLuxDiff (mean [luxDiff] of $occupantset)
    let $tasklightlux (zoneTaskLightNum * 228)
    set zoneLuminanceSetPoint (((mean comfortLux + $meanLuxDiff) / luxFraction) - (zoneDaylightLux + $tasklightlux))
  ]
  if (self = one-of managers) [ (ManagerTblIncr "lightActOverheadLightCount") ]
  if (self = one-of occupants) [ OccupantTblSet "lightActOverheadLight" true]
end
@#$#@#$#@
GRAPHICS-WINDOW
129
1207
374
1403
-1
-1
82.5
1
10
1
1
1
0
1
1
1
0
1
0
1
0
0
1
ticks
30.0

SWITCH
482
228
590
261
SimThermal
SimThermal
0
1
-1000

SWITCH
482
261
590
294
SimLighting
SimLighting
0
1
-1000

BUTTON
513
16
576
49
setup
setup 1
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
581
16
644
49
go
go 1
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
340
62
431
107
Weekday
weekdayStr
17
1
11

MONITOR
435
62
492
107
Time
word endingHour \":00\"
17
1
11

MONITOR
339
15
389
60
Month
currentMonth
17
1
11

MONITOR
390
14
440
59
Day
currentDay
17
1
11

MONITOR
442
14
492
59
Year
currentYear
17
1
11

PLOT
22
160
323
310
Thermal Discomfort
Hour
Discomfort
0.0
24.0
0.0
1.0
true
true
"" ""
PENS
"begin hour" 1.0 0 -8053223 true "" "plot BldgThermalDiscomfort 0"
"thermostat" 1.0 0 -5298144 true "" "plot BldgThermalDiscomfort 1"
"individual 1" 1.0 0 -2674135 true "" "plot BldgThermalDiscomfort 2"
"individual 2" 1.0 0 -2139308 true "" "plot BldgThermalDiscomfort 3"
"individual 3" 1.0 0 -1604481 true "" "plot BldgThermalDiscomfort 4"
"end hour" 1.0 0 -534828 true "" "plot BldgThermalDiscomfort 5"

PLOT
663
310
969
458
Manager Responsiveness
NIL
NIL
0.0
24.0
0.0
2.0
true
true
"" ""
PENS
"Thermostat" 1.0 0 -2674135 true "" "plot sum [ManagerTblGet \"thermalActThermostatCount\"] of managers"
"Overhead Light" 1.0 0 -10899396 true "" "plot sum [ManagerTblGet \"lightActOverheadLightCount\"] of managers"
"Do Nothing" 1.0 0 -7500403 true "" "plot sum [ManagerTblGet \"ActDoNothingCount\"] of managers"

PLOT
323
457
663
607
Predicted Mean Vote
Hour
PMV
0.0
24.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot mean ([pmvValue] of occupants)"

INPUTBOX
590
227
651
293
CentsKWH
0.2
1
0
Number

PLOT
323
308
663
457
KWH (Energy+)
NIL
NIL
0.0
24.0
0.0
10.0
true
true
"" ""
PENS
"Total" 1.0 0 -16777216 true "" "plot (round electricityCost bldgElectricity)"
"Equipment" 1.0 0 -2674135 true "" "plot (round electricityCost bldgEquipmentElectricity)"
"InteriorLights" 1.0 0 -11221820 true "" "plot (round electricityCost bldgInteriorLightsElectricity)"
"HVAC" 1.0 0 -10899396 true "" "plot (round electricityCost bldgHVACElectricity)"

PLOT
663
10
969
160
Individual Adaptive Behavior
NIL
NIL
0.0
24.0
0.0
0.0
true
true
"" ""
PENS
"Task Light" 1.0 0 -2674135 true "" "plot count occupants with [OccupantTblGet \"lightActTaskLight\"]"
"Window Blinds" 1.0 0 -955883 true "" "plot count occupants with [OccupantTblGet \"lightActWindowBlinds\"]"
"Change Clothes" 1.0 0 -11221820 true "" "plot count occupants with [OccupantTblGet \"thermalActClothes\"]"
"Portable Fan" 1.0 0 -6459832 true "" "plot count occupants with [OccupantTblGet \"thermalActFan\"]"
"Portable Heater" 1.0 0 -16777216 true "" "plot count occupants with [OccupantTblGet \"thermalActHeater\"]"

CHOOSER
340
176
477
221
eplus_fname
eplus_fname
"335Com_NLS.csv" "335Com_LS.csv" "Bldg101_NLS.csv"
0

CHOOSER
340
221
477
266
occupant_fname
occupant_fname
"in_occupantdata_mix.csv"
0

CHOOSER
482
183
651
228
ScenarioClo
ScenarioClo
"Heavy Clothing" "Light Clothing" "Allow Change"
1

SWITCH
482
150
651
183
ZoneControl
ZoneControl
1
1
-1000

BUTTON
513
53
644
86
NIL
runScenario
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
482
117
651
150
Communication
Communication
1
1
-1000

INPUTBOX
340
118
477
178
output_fname
AllExperiment.csv
1
0
String

PLOT
22
457
323
607
Lighting Discomfort
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"begin hour" 1.0 0 -15040220 true "" "plot BldgLightDiscomfort 0"
"overhead light" 1.0 0 -14439633 true "" "plot BldgLightDiscomfort 1"
"individual 1" 1.0 0 -13840069 true "" "plot BldgLightDiscomfort 2"
"individual 2" 1.0 0 -11085214 true "" "plot BldgLightDiscomfort 3"
"individual 3" 1.0 0 -8330359 true "" "plot BldgLightDiscomfort 4"
"end hour" 1.0 0 -5509967 true "" "plot BldgLightDiscomfort 5"

PLOT
663
159
969
310
Fixtures in Use
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Portable Heater" 1.0 0 -16777216 true "" "plot count occupants with [portableHeaterON?]"
"Portable Fan" 1.0 0 -6459832 true "" "plot count occupants with [portableFanON?]"
"Task Light" 1.0 0 -2674135 true "" "plot count occupants with [taskLightON?]"
"Window Blinds" 1.0 0 -10899396 true "" "plot count occupants with [WindowBlindsOpen?]"

PLOT
1329
182
1669
332
Mean Zone Air Temperature
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Air Temp (E+)" 1.0 0 -2674135 true "" "plot 9 / 5 * (mean [meanAirT] of zones) + 32"
"Temp SetPoint" 1.0 0 -7500403 true "" "plot bldgMeanTemperatureSP"

PLOT
22
10
323
160
Thermal Perception (begin hour)
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Too Cold" 1.0 0 -11221820 true "" "plot count occupants with [OccupantTblGet \"thermalPerception0\" = \"too cold\"]"
"Too Hot" 1.0 0 -2674135 true "" "plot count occupants with [OccupantTblGet \"thermalPerception0\" = \"too hot\"]"
"Normal" 1.0 0 -10899396 true "" "plot count occupants with [OccupantTblGet \"thermalPerception0\" = \"normal\"]"

PLOT
22
309
323
459
Lighting Perception (begin hour)
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Too Dark" 1.0 0 -7500403 true "" "plot count occupants with [OccupantTblGet \"lightPerception0\" = \"too dark\"]"
"Too Bright" 1.0 0 -955883 true "" "plot count occupants with [OccupantTblGet \"lightPerception0\" = \"too bright\"]"
"Normal" 1.0 0 -10899396 true "" "plot count occupants with [OccupantTblGet \"lightPerception0\" = \"normal\"]"

BUTTON
1690
11
1795
45
Experiment 1
set SimThermal true\nset SimLighting true\nset output_fname \"Experiment01.csv\"\nset eplus_fname \"335Com_LS.csv\"\nset occupant_fname \"in_occupantdata_mix.csv\"\nset ScenarioClo \"Allow Change\"\nset Communication true\nset ZoneControl false\n\n\nsetup 1\ngo 1
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
1684
44
2006
1124
----------------------------------------------\nParameters Setting - Load Shedding\n----------------------------------------------\nSimThermal=T                  SimLighting=T\noutput_fname=\"Experiment01.csv\"\neplus_fname=\"335Com_LS.csv\"\noccupant_fname=\"in_occupantdata_.csv\"\nScenarioClo=\"Allow Change\"    ZoneControl=F\nCommunication=T           DiscomfortAdder=F\n\n----------------------------------------------\nOutput Explanation\n----------------------------------------------\nKWH (Energy+)\n----------------------------------------------\nThis is an Energy+ results without behavioral effects\n\nPMV\n----------------------------------------------\nPMV Value recorded at the beginning \n\nMean Zone Air Temperature\n----------------------------------------------\nAir temperature (E+) is set by Energy+\nTemp SetPoint is a thermostat setting set by, in this scenario, a Building Manager.\n\nThermal Perception (begin hour)\n----------------------------------------------\nNumber of occupants either feeling too cold, too hot, or normal temperature, recorded before any adaptive actions are performed.\n\nLighting Perception (begin hour)\n----------------------------------------------\nNumber of occupants either feeling too dark, too bright, or normal lighting, recorded before any adaptive actions are performed.\n\nThermal Discomfort\n----------------------------------------------\nNumber of occupants either feeling too hot or too cold, recorded as \"not feeling discomfort\" at 1)before performing any action, 2)after BM adjust thermostat, 3-4) at the end of every adaptive action.\n\nLighting Discomfort\n----------------------------------------------\nNumber of occupants either feeling too dark or too bright, recorded as \"not feeling discomfort\" at 1)before performing any action, 2)after BM adjust thermostat, 3-4) at the end of every adaptive action.\n\nManager Responsiveness\n----------------------------------------------\nCounts of manager's adaptive responses for every action.\n\nManager Responsiveness\n----------------------------------------------\nCounts of tenant representative's adaptive responses for every action. Tenant representative is an appointed occupant in a zone.\n\nIndividual Adaptive Behavior\n----------------------------------------------\nCounts of manager's adaptive responses for every action.\n\nFixtures in Use\n----------------------------------------------\nFixtures being used\n
11
0.0
1

PLOT
663
457
969
607
Tenant Representative
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Thermostat" 1.0 0 -2674135 true "" "plot count occupants with [OccupantTblGet \"thermalActThermostat\"]"
"Overhead Light" 1.0 0 -10899396 true "" "plot count occupants with [OccupantTblGet \"lightActOverheadLight\"]"

BUTTON
1436
10
1541
44
Experiment 2
set SimThermal true\nset SimLighting true\nset output_fname \"Experiment02.csv\"\nset eplus_fname \"335Com_NLS.csv\"\nset occupant_fname \"in_occupantdata_mix.csv\"\nset ScenarioClo \"Allow Change\"\nset Communication true\nset ZoneControl false\n\nsetup 1\ngo 1
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
1395
45
1678
174
----------------------------------------------\nParameters Setting - Non-Load Shedding\n----------------------------------------------\nSimThermal=T                  SimLighting=T\noutput_fname=\"Experiment02.csv\"\neplus_fname=\"335Com_NLS.csv\"\noccupant_fname=\"in_occupantdata_.csv\"\nScenarioClo=\"Allow Change\"    ZoneControl=F\nCommunication=T           DiscomfortAdder=F\n
11
0.0
1

@#$#@#$#@
## RESULTS
- More controls on certain zones
- locus of control
 -- Owner-occupant
 -- Multi-tenant
 -- Single-tenant
 -- Friendly tenant representative
- Technological strategies
 -- more control zones
- Clothing behaviors: suits for corporate office, casual friday, gender
- Dashboard & energy chicken
- Automation (smart building that anticipate people wants)
 -- create building sensor agents within NetLogo


## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1"/>
    <metric>output_fname</metric>
    <metric>eplus_fname</metric>
    <metric>occupant_fname</metric>
    <metric>CommunicationLevel</metric>
    <metric>BldgControlLevel</metric>
    <metric>round TotalBldgCost</metric>
    <metric>CountOccupantsWithPMV 3</metric>
    <metric>CountOccupantsWithPMV 2</metric>
    <metric>CountOccupantsWithPMV 1</metric>
    <metric>CountOccupantsWithPMV 0</metric>
    <metric>CountOccupantsWithPMV -1</metric>
    <metric>CountOccupantsWithPMV -2</metric>
    <metric>CountOccupantsWithPMV -3</metric>
    <metric>TotalBldgThermalDiscomfort</metric>
    <metric>TotalBldgLightingDiscomfort</metric>
    <metric>TotalOccupantEffort</metric>
    <metric>TotalTenantRepEffort</metric>
    <metric>TenantRepReportReceived</metric>
    <metric>(TenantRepReportReceived - TenantRepDoNothing)</metric>
    <metric>TotalTenantRepReportSent</metric>
    <metric>(TotalTenantRepReportSent - TotalManagerDoNothing)</metric>
    <metric>(sum [occTaskLightCurrHour] of occupants)</metric>
    <metric>(sum [occWindowsBlindCurrHour] of occupants)</metric>
    <metric>(sum [occClothesCurrHour] of occupants)</metric>
    <metric>(sum [occPortHeaterCurrHour] of occupants)</metric>
    <metric>(sum [occReportSentCurrHour] of occupants)</metric>
    <metric>(sum [mnThermostatCt] of managers)</metric>
    <metric>(sum [trOverheadLightCt] of tenantreps)</metric>
    <enumeratedValueSet variable="occupant_fname">
      <value value="&quot;in_occupantdata_cost.csv&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="CentsKWH">
      <value value="0.12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SimLighting">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="BldgControlLevel">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="eplus_fname">
      <value value="&quot;eplusoutput_winter.csv&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="CommunicationLevel">
      <value value="0"/>
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ScenarioClo">
      <value value="&quot;Allow Change&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="SimThermal">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
